#
# spec file for package python-Flask-HTTPAuth
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}
Name:           python-Flask-HTTPAuth
Version:        4.8.0
Release:        2.3
Summary:        Basic and Digest HTTP authentication for Flask routes
License:        MIT
URL:            https://github.com/miguelgrinberg/flask-httpauth/
Source:         https://files.pythonhosted.org/packages/source/F/Flask-HTTPAuth/Flask-HTTPAuth-%{version}.tar.gz
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module asgiref >= 3.2}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Recommends:     python-asgiref >= 3.2
BuildArch:      noarch
%python_subpackages

%description
Simple extension that provides Basic and Digest HTTP authentication for Flask routes.

%prep
%setup -q -n Flask-HTTPAuth-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/flask_httpauth.py*
%{python_sitelib}/Flask_HTTPAuth-%{version}.dist-info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Mon Jan 22 2024 Axel Braun <axel.braun@gmx.de>
- enable %%{?sle15_python_module_pythons}
* Thu Jul 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.8.0:
  * Changes to handle breaking changes in Flask/Werkzeug 2.3 #160
  * Replace itsdangerous with pyjwt in examples #157
  * Fallback to latin-1 encoding for credentials when utf-8 fails #151
  * Add MD5-Sess algorithm for Digest auth
  * Add qop=auth option for Digest auth (thanks Edward!)
  * Do not read the request body #138
- Switch to pyproject and pytest macros.
* Tue Sep 14 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sun Jul  4 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * require importlib-metadata
  * skip python 2
- update to version 4.4.0:
  * Replace safe_str_cmp with hmac.compare_digest to avoid a
    deprecation warning from Werkzeug #126 (commit) (thanks Federico
    Martinez!)
  * Drop Python 2 support (commit)
- changes from version 4.3.0 :
  * Support token auth with custom header in MultiAuth class #125
    (commit)
  * Catch UnicodeDecodeError when passing malformed data in
    authorization header #122 (commit) (thanks Bastian Raschke!)
  * Fixes typo #116 (commit) (thanks Renato Oliveira!)
  * Move builds to GitHub actions (commit)
* Thu Nov 26 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 4.2.0:
  * Allow error response to return a 200 status code #114 (commit)
  * Add optional argument to MultiAuth class #115 (commit) (thanks
    pryankster and Michael Wright!)
  * Remove python 3.5 and add python 3.9 to build (commit)
* Sun Jun 28 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 4.1.0:
  * Basic authentication with custom scheme (commit)
* Sat May  2 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
- update to version 4.0.0:
  * Return user object from verify callbacks (commit)
  * New role authorization support (commit) (thanks gemerden!)
  * Add a custom token authorization header option (commit) (thanks
    Mohamed Feddad!)
  * Support an optional=True argument in login_required decorator
    (commit) (thanks Saif Almansoori!)
  * Pass HTTP status code to error callback (commit)
  * More secure example of basic auth in the documentation (commit)
  * Fix broken links in CHANGES.md and changelog template #85 (commit)
    (thanks Katie Smith!)
* Tue May 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.0:
  * Use constant time string comparisons #82 (commit1, commit2) (thanks Brendan Long!)
  * Edited and changed the usage of JWT, because in fact the code and documentation uses JWS tokens. #79 (commit) (thanks unuseless!)
  * Documentation improvements #77 (commit)
* Tue Oct 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.4:
  * Various spelling fixes
  * Refactored HTTPAuth login_required
* Sat Nov 25 2017 axel.braun@gmx.de
- Version 3.2.3
  initial OBS build
